==> gcube-model-6.0.0-20250917.161622-9-sources.jar: org/gcube/resourcemanagement/model/impl/entities/facets/ContactFacetImpl.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.model.impl.entities.facets;

import java.io.Serial;


import org.gcube.com.fasterxml.jackson.annotation.JsonProperty;
import org.gcube.com.fasterxml.jackson.annotation.JsonTypeName;
import org.gcube.informationsystem.model.impl.entities.FacetImpl;
import org.gcube.resourcemanagement.model.reference.entities.facets.ContactFacet;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonTypeName(value=ContactFacet.NAME)
public class ContactFacetImpl extends FacetImpl implements ContactFacet {

	/**
	 * Generated Serial version UID
	 */
	@Serial
	private static final long serialVersionUID = -4036703255922676717L;
	
	protected String title;
	protected String name;
	protected String middleName;
	protected String surname;
	protected String eMail;
	
	
	@Override
	public String getTitle() {
		return this.title;
	}

	@Override
	public void setTitle(String title) {
		this.title = title;
	}

	
	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public void setName(String name) {
		this.name = name;
	}

	
	@Override
	public String getMiddleName() {
		return this.middleName;
	}

	@Override
	public void setMiddleName(String middleName) {
		this.middleName = middleName;
	}

	
	@Override
	public String getSurname() {
		return this.surname;
	}

	@Override
	public void setSurname(String surname) {
		this.surname = surname;
	}

	
	@JsonProperty(EMAIL_PROPERTY)
	@Override
	public String getEMail() {
		return this.eMail;
	}

	@Override
	public void setEMail(String eMail) {
		this.eMail = eMail;
	}


}

==> gcube-model-6.0.0-20251215.133228-7-sources.jar: org/gcube/resourcemanagement/model/impl/entities/facets/ContactFacetImpl.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.model.impl.entities.facets;

import java.io.Serial;

import org.gcube.com.fasterxml.jackson.annotation.JsonProperty;
import org.gcube.com.fasterxml.jackson.annotation.JsonTypeName;
import org.gcube.informationsystem.model.impl.entities.FacetImpl;
import org.gcube.resourcemanagement.model.reference.entities.facets.ContactFacet;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonTypeName(value=ContactFacet.NAME)
public class ContactFacetImpl extends FacetImpl implements ContactFacet {

	/**
	 * Generated Serial version UID
	 */
	@Serial
	private static final long serialVersionUID = -4036703255922676717L;
	
	protected String id;
	protected String title;
	protected String name;
	protected String middleName;
	protected String surname;
	protected String eMail;
	
	@Override
	public String getId() {
		return this.id;
	}

	@Override
	public void setId(String id) {
		this.id = id;
	}

	@Override
	public String getTitle() {
		return this.title;
	}

	@Override
	public void setTitle(String title) {
		this.title = title;
	}

	
	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public void setName(String name) {
		this.name = name;
	}

	
	@Override
	public String getMiddleName() {
		return this.middleName;
	}

	@Override
	public void setMiddleName(String middleName) {
		this.middleName = middleName;
	}

	
	@Override
	public String getSurname() {
		return this.surname;
	}

	@Override
	public void setSurname(String surname) {
		this.surname = surname;
	}

	
	@JsonProperty(EMAIL_PROPERTY)
	@Override
	public String getEMail() {
		return this.eMail;
	}

	@Override
	public void setEMail(String eMail) {
		this.eMail = eMail;
	}


}
